import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '敏感类型搜索',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '敏感类型',
    },
    componentProps: {
      options: [
        { label: 'IP地址', value: 'IP地址' },
        { label: '军官证', value: '军官证' },
        { label: '固定电话', value: '固定电话' },
      ],
    },
  },
  {
    field: 'safetyLevel',
    label: ' ',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '安全分级',
    },
    componentProps: {
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'describe',
    width: 120,
  },
  {
    title: '敏感类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '安全分级',
    dataIndex: 'safetyLevel',
    width: 140,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 140,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 180,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '描述',
    componentProps: {
      placeholder: '请输入描述',
      rows: 4,
    },
  },
  {
    field: 'type',
    label: '敏感类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'IP地址', value: 'IP地址' },
        { label: '军官证', value: '军官证' },
        { label: '固定电话', value: '固定电话' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择敏感类型',
      },
    ],
  },
  {
    field: 'safetyLevel',
    label: '安全分级',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择安全分级',
      },
    ],
  },
  {
    field: 'matchMethod',
    label: '匹配方式',
    component: 'Select',
    componentProps: {
      options: [
        { label: '正则表达式', value: '正则表达式' },
        { label: '校验', value: '校验' },
      ],
    },
  },
  {
    field: 'regular',
    component: 'InputTextArea',
    label: '正则表达式',
    componentProps: {
      placeholder: '请输入正则表达式',
      rows: 4,
    },
    rules: [
      {
        required: true,
        message: '请输入正则表达式',
      },
    ],
  },

]
